===============================
networking-vsphere
===============================

A set of Neutron drivers and agents to manage vSphere clusters.

* Free software: Apache license
* Source: http://git.openstack.org/cgit/openstack/networking-vsphere
* Bugs: https://bugs.launchpad.net/networking-vsphere

OVSvApp Solution
----------------

OVSvApp solution comprises of a service VM called OVSvApp VM hosted on each
ESXi hypervisor within a cluster and two vSphere Distributed Switches (VDS).

Features
--------

* Supports VLAN and VXLAN based networks.
* Security Groups.
* vMotion.

More information
----------------

For help using or hacking on OVSvApp solution, you can send an email to the
`OpenStack Development Mailing List <mailto:openstack-dev@lists.openstack.org>`;
kindly use the [Networking-vSphere] Tag in the subject.

Getting started
---------------

https://wiki.openstack.org/wiki/Neutron/Networking-vSphere
